@@ -13,19 +13,22 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
+
+from botocore.response import StreamingBody
 
 from .literals import (
     BatchItemErrorCodeType,
     DimensionUnitType,
     DistanceUnitType,
     IntendedUseType,
+    PositionFilteringType,
     PricingPlanType,
     TravelModeType,
     VehicleWeightUnitType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -181,7 +184,7 @@ BatchDeleteDevicePositionHistoryErrorTypeDef = TypedDict(
 BatchDeleteDevicePositionHistoryRequestRequestTypeDef = TypedDict(
     "BatchDeleteDevicePositionHistoryRequestRequestTypeDef",
     {
-        "DeviceIds": List[str],
+        "DeviceIds": Sequence[str],
         "TrackerName": str,
     },
 )
@@ -206,7 +209,7 @@ BatchDeleteGeofenceRequestRequestTypeDef = TypedDict(
     "BatchDeleteGeofenceRequestRequestTypeDef",
     {
         "CollectionName": str,
-        "GeofenceIds": List[str],
+        "GeofenceIds": Sequence[str],
     },
 )
 
@@ -231,7 +234,7 @@ BatchEvaluateGeofencesRequestRequestTypeDef = TypedDict(
     "BatchEvaluateGeofencesRequestRequestTypeDef",
     {
         "CollectionName": str,
-        "DevicePositionUpdates": List["DevicePositionUpdateTypeDef"],
+        "DevicePositionUpdates": Sequence["DevicePositionUpdateTypeDef"],
     },
 )
 
@@ -254,7 +257,7 @@ BatchGetDevicePositionErrorTypeDef = TypedDict(
 BatchGetDevicePositionRequestRequestTypeDef = TypedDict(
     "BatchGetDevicePositionRequestRequestTypeDef",
     {
-        "DeviceIds": List[str],
+        "DeviceIds": Sequence[str],
         "TrackerName": str,
     },
 )
@@ -297,7 +300,7 @@ BatchPutGeofenceRequestRequestTypeDef = TypedDict(
     "BatchPutGeofenceRequestRequestTypeDef",
     {
         "CollectionName": str,
-        "Entries": List["BatchPutGeofenceRequestEntryTypeDef"],
+        "Entries": Sequence["BatchPutGeofenceRequestEntryTypeDef"],
     },
 )
 
@@ -332,7 +335,7 @@ BatchUpdateDevicePositionRequestRequestTypeDef = TypedDict(
     "BatchUpdateDevicePositionRequestRequestTypeDef",
     {
         "TrackerName": str,
-        "Updates": List["DevicePositionUpdateTypeDef"],
+        "Updates": Sequence["DevicePositionUpdateTypeDef"],
     },
 )
 
@@ -357,8 +360,8 @@ _RequiredCalculateRouteRequestRequestTypeDef = TypedDict(
     "_RequiredCalculateRouteRequestRequestTypeDef",
     {
         "CalculatorName": str,
-        "DeparturePosition": List[float],
-        "DestinationPosition": List[float],
+        "DeparturePosition": Sequence[float],
+        "DestinationPosition": Sequence[float],
     },
 )
 _OptionalCalculateRouteRequestRequestTypeDef = TypedDict(
@@ -371,7 +374,7 @@ _OptionalCalculateRouteRequestRequestTypeDef = TypedDict(
         "IncludeLegGeometry": bool,
         "TravelMode": TravelModeType,
         "TruckModeOptions": "CalculateRouteTruckModeOptionsTypeDef",
-        "WaypointPositions": List[List[float]],
+        "WaypointPositions": Sequence[Sequence[float]],
     },
     total=False,
 )
@@ -427,7 +430,7 @@ _OptionalCreateGeofenceCollectionRequestRequestTypeDef = TypedDict(
         "Description": str,
         "KmsKeyId": str,
         "PricingPlanDataSource": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -462,7 +465,7 @@ _OptionalCreateMapRequestRequestTypeDef = TypedDict(
     "_OptionalCreateMapRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -497,7 +500,7 @@ _OptionalCreatePlaceIndexRequestRequestTypeDef = TypedDict(
     {
         "DataSourceConfiguration": "DataSourceConfigurationTypeDef",
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -531,7 +534,7 @@ _OptionalCreateRouteCalculatorRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRouteCalculatorRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -566,8 +569,9 @@ _OptionalCreateTrackerRequestRequestTypeDef = TypedDict(
     {
         "Description": str,
         "KmsKeyId": str,
+        "PositionFiltering": PositionFilteringType,
         "PricingPlanDataSource": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -736,6 +740,7 @@ DescribeTrackerResponseTypeDef = TypedDict(
         "CreateTime": datetime,
         "Description": str,
         "KmsKeyId": str,
+        "PositionFiltering": PositionFilteringType,
         "PricingPlan": PricingPlanType,
         "PricingPlanDataSource": str,
         "Tags": Dict[str, str],
@@ -771,7 +776,7 @@ DevicePositionUpdateTypeDef = TypedDict(
     "DevicePositionUpdateTypeDef",
     {
         "DeviceId": str,
-        "Position": List[float],
+        "Position": Sequence[float],
         "SampleTime": Union[datetime, str],
     },
 )
@@ -787,7 +792,7 @@ DisassociateTrackerConsumerRequestRequestTypeDef = TypedDict(
 GeofenceGeometryTypeDef = TypedDict(
     "GeofenceGeometryTypeDef",
     {
-        "Polygon": List[List[List[float]]],
+        "Polygon": Sequence[Sequence[Sequence[float]]],
     },
     total=False,
 )
@@ -877,7 +882,7 @@ GetMapGlyphsRequestRequestTypeDef = TypedDict(
 GetMapGlyphsResponseTypeDef = TypedDict(
     "GetMapGlyphsResponseTypeDef",
     {
-        "Blob": bytes,
+        "Blob": StreamingBody,
         "ContentType": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -894,7 +899,7 @@ GetMapSpritesRequestRequestTypeDef = TypedDict(
 GetMapSpritesResponseTypeDef = TypedDict(
     "GetMapSpritesResponseTypeDef",
     {
-        "Blob": bytes,
+        "Blob": StreamingBody,
         "ContentType": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -910,7 +915,7 @@ GetMapStyleDescriptorRequestRequestTypeDef = TypedDict(
 GetMapStyleDescriptorResponseTypeDef = TypedDict(
     "GetMapStyleDescriptorResponseTypeDef",
     {
-        "Blob": bytes,
+        "Blob": StreamingBody,
         "ContentType": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -929,7 +934,7 @@ GetMapTileRequestRequestTypeDef = TypedDict(
 GetMapTileResponseTypeDef = TypedDict(
     "GetMapTileResponseTypeDef",
     {
-        "Blob": bytes,
+        "Blob": StreamingBody,
         "ContentType": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -1372,7 +1377,7 @@ _RequiredSearchPlaceIndexForPositionRequestRequestTypeDef = TypedDict(
     "_RequiredSearchPlaceIndexForPositionRequestRequestTypeDef",
     {
         "IndexName": str,
-        "Position": List[float],
+        "Position": Sequence[float],
     },
 )
 _OptionalSearchPlaceIndexForPositionRequestRequestTypeDef = TypedDict(
@@ -1433,9 +1438,9 @@ _RequiredSearchPlaceIndexForTextRequestRequestTypeDef = TypedDict(
 _OptionalSearchPlaceIndexForTextRequestRequestTypeDef = TypedDict(
     "_OptionalSearchPlaceIndexForTextRequestRequestTypeDef",
     {
-        "BiasPosition": List[float],
-        "FilterBBox": List[float],
-        "FilterCountries": List[str],
+        "BiasPosition": Sequence[float],
+        "FilterBBox": Sequence[float],
+        "FilterCountries": Sequence[str],
         "MaxResults": int,
     },
     total=False,
@@ -1510,7 +1515,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -1538,7 +1543,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1684,6 +1689,7 @@ _OptionalUpdateTrackerRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateTrackerRequestRequestTypeDef",
     {
         "Description": str,
+        "PositionFiltering": PositionFilteringType,
         "PricingPlan": PricingPlanType,
         "PricingPlanDataSource": str,
     },
